*grimace* is a fluent regular expression string builder for Python.
Inspired by Al Williams' article in Dr Dobbs:
http://www.drdobbs.com/embedded-systems/irregular-expressions/240157655#
Ben Last <ben@benlast.com>
Python3 support (ands bugfixes) by Nando Florestan

* Documentation_
* `Project home`_

.. _Documentation: https://github.com/benlast/grimace/wiki
.. _`Project home`: https://github.com/benlast/grimace
